@@ -14,7 +14,7 @@ use English qw/ -no_match_vars /;
 use Term::ANSIColor qw/:constants/;
 use Term::Size::Any;
 
-our $VERSION     = version->new('0.6.0');
+our $VERSION = version->new('0.7.0');
 
 extends 'File::CodeSearch::RegexBuilder';
 
@@ -80,7 +80,7 @@ sub make_highlight_re {
 
 sub highlight {
     my ($self, $string) = @_;
-    my $re  = $self->highlight_re || $self->make_highlight_re;
+    my $re  = $self->make_highlight_re;
     my $out = '';
 
     my @parts = split /($re)/, $string;
@@ -91,6 +91,7 @@ sub highlight {
             $match_length += length $parts[$i];
         }
     }
+
     # 5 is the magic number of characters used to show the line number
     my $limit = $self->limit - $match_length - 5;
     my $joins = @parts - ( @parts - 1 ) / 2;
@@ -101,7 +102,7 @@ sub highlight {
     if (length $parts[-1] < $chars * 2) {
         $total -= $chars_front + $chars_back - length $parts[-1];
     }
-    #warn "Big\n" if $limit - $total > $joins * 2;
+
     my $inc = $limit - $total > $joins * 2 ? 1 : 0;
     $chars += $inc;
     $chars_front = int $chars;
@@ -129,6 +130,7 @@ sub highlight {
                     $chars_back_tmp++;
                     $total++;
                 }
+
                 # Check if
                 if ($chars_front_tmp + $chars_back_tmp < length $parts[$i]) {
                     my ($front) = $parts[$i] =~ /\A (.{$chars_front_tmp}) /xms;
@@ -141,7 +143,7 @@ sub highlight {
     }
 
     $out .= RESET;
-    $out .= "\\N\n" if $string !~ /\n/xms;
+    $out .= "\\N" if $string !~ /\n/xms;
     $out .= "\n" if $out !~ /\n/xms;
 
     return $out;
@@ -157,7 +159,7 @@ File::CodeSearch::Highlighter - Highlights matched parts of a line.
 
 =head1 VERSION
 
-This documentation refers to File::CodeSearch::Highlighter version 0.6.0.
+This documentation refers to File::CodeSearch::Highlighter version 0.7.0.
 
 
 =head1 SYNOPSIS
